@@ -12,7 +12,7 @@ use FormValidator::Simple::Validator;
 use FormValidator::Simple::Constants;
 use FormValidator::Simple::Messages;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 __PACKAGE__->mk_classaccessors(qw/data prof results/);
 __PACKAGE__->mk_classaccessor( messages => FormValidator::Simple::Messages->new );
@@ -65,6 +65,11 @@ sub set_messages {
     }
 }
 
+sub set_message_decode_from {
+    my ($self, $decode_from) = @_;
+    $self->messages->decode_from($decode_from);
+}
+
 sub set_message_format {
     my ($proto, $format) = @_;
     $format ||= '';
@@ -151,7 +156,6 @@ sub check {
 }
 
 1;
-__END__
 
 =head1 NAME
 
@@ -654,6 +658,13 @@ you can set each message format.
 
 See L<FormValidator::Simple::Results>
 
+=head1 FLAGGED UTF-8
+
+If you set encoding like follows, it automatically decode the
+result messages.
+
+    FormValidtor::Simple->set_mesasges_decode_from('utf-8');
+
 =head1 SEE ALSO
 
 L<Data::FormValidator>
